@@ -7,7 +7,7 @@ package Sub::HandlesVia;
 use Exporter::Shiny qw( delegations );
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.009';
+our $VERSION   = '0.010';
 
 sub _generate_delegations {
 	my ($me, $name, $args, $globals) = (shift, @_);
@@ -344,7 +344,7 @@ array index.)
 =head2 What methods can be delegated to?
 
 The following table compares Sub::HandlesVia with L<Data::Perl>, L<Moose>
-native traits, and L<MouseX::NativeTraits>. Mouse L<looks> like it's
+native traits, and L<MouseX::NativeTraits>. Mouse I<looks> like it's
 ahead of the rest, but quite a few of their extra methods are just
 aliases for existing methods.
 
@@ -352,7 +352,7 @@ aliases for existing methods.
             accessor : SubHV  DataP  Moose  Mouse
                  all : SubHV  DataP              
                  any :                      Mouse
-               apply :                      Mouse
+               apply : SubHV                Mouse
                clear : SubHV  DataP  Moose  Mouse
                count : SubHV  DataP  Moose  Mouse
               delete : SubHV  DataP  Moose  Mouse
@@ -362,8 +362,8 @@ aliases for existing methods.
          first_index : SubHV  DataP  Moose       
              flatten : SubHV  DataP              
         flatten_deep : SubHV  DataP              
-            for_each :                      Mouse
-       for_each_pair :                      Mouse
+            for_each : SubHV                Mouse
+       for_each_pair : SubHV                Mouse
                  get : SubHV  DataP  Moose  Mouse
                 grep : SubHV  DataP  Moose  Mouse
                 head : SubHV  DataP              
@@ -372,6 +372,7 @@ aliases for existing methods.
                 join : SubHV  DataP  Moose  Mouse
                  map : SubHV  DataP  Moose  Mouse
             natatime : SubHV  DataP  Moose       
+         pick_random : SubHV                     
                  pop : SubHV  DataP  Moose  Mouse
                print : SubHV  DataP              
                 push : SubHV  DataP  Moose  Mouse
@@ -421,9 +422,9 @@ aliases for existing methods.
             elements : SubHV  DataP  Moose  Mouse
               exists : SubHV  DataP  Moose  Mouse
                fetch :                      Mouse
-        for_each_key :                      Mouse
-       for_each_pair :                      Mouse
-      for_each_value :                      Mouse
+        for_each_key : SubHV                Mouse
+       for_each_pair : SubHV                Mouse
+      for_each_value : SubHV                Mouse
                  get : SubHV  DataP  Moose  Mouse
             is_empty : SubHV  DataP  Moose  Mouse
                 keys : SubHV  DataP  Moose  Mouse
